.wp-block-media-text__media {
  position: relative;
}
.wp-block-media-text__media.is-transient img {
  opacity: 0.3;
}
.wp-block-media-text__media .components-spinner {
  position: absolute;
  top: 50%;
  right: 50%;
  margin-top: -9px;
  margin-right: -9px;
}

.wp-block-media-text .__resizable_base__ {
  grid-column: 1/span 2;
  grid-row: 2;
}

.wp-block-media-text .editor-media-container__resizer {
  width: 100% !important;
}

.wp-block-media-text.is-image-fill .editor-media-container__resizer,
.wp-block-media-text.is-image-fill .components-placeholder.has-illustration,
.wp-block-media-text.is-image-fill-element .editor-media-container__resizer,
.wp-block-media-text.is-image-fill-element .components-placeholder.has-illustration {
  height: 100% !important;
}

.wp-block-media-text > .block-editor-block-list__layout > .block-editor-block-list__block {
  max-width: unset;
}

/* Make the featured image placeholder the same height as the media selection area. */
.wp-block-media-text--placeholder-image {
  min-height: 205px;
}