.wp-block-audio {
  margin-left: 0;
  margin-right: 0;
  position: relative;
}
.wp-block-audio.is-transient audio {
  opacity: 0.3;
}
.wp-block-audio .components-spinner {
  position: absolute;
  top: 50%;
  left: 50%;
  margin-top: -9px;
  margin-left: -9px;
}