/**
 * Colors
 */
.wp-block-file {
  box-sizing: border-box;
}
.wp-block-file:not(.wp-element-button) {
  font-size: 0.8em;
}
.wp-block-file.aligncenter {
  text-align: center;
}
.wp-block-file.alignright {
  /*rtl:ignore*/
  text-align: right;
}
.wp-block-file * + .wp-block-file__button {
  margin-left: 0.75em;
}

:where(.wp-block-file) {
  margin-bottom: 1.5em;
}

.wp-block-file__embed {
  margin-bottom: 1em;
}

:where(.wp-block-file__button) {
  border-radius: 2em;
  padding: 0.5em 1em;
  display: inline-block;
}
:where(.wp-block-file__button):where(a):hover, :where(.wp-block-file__button):where(a):visited, :where(.wp-block-file__button):where(a):focus, :where(.wp-block-file__button):where(a):active {
  box-shadow: none;
  color: #fff;
  opacity: 0.85;
  text-decoration: none;
}